﻿/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * 
 */
using System;
// Remote Api C# client using directives
// Note: these needs Hessiancsharp.dll and RemoteApi.dll
using hessiancsharp.client;
using com.intland.codebeamer.persistence.dto;
using com.intland.codebeamer.remoting.samples.util;
using System.Net.Security;
using System.Net;
using System.Security.Cryptography.X509Certificates;

namespace com.intland.codebeamer.remoting.samples
{
    class IssueSample
    {
        private static string hostname = System.Environment.MachineName;

        private static string protocol = "http";

        private static string port = "8080";

        private static string cbcontext = "/cb";

        /// <summary>Remote API instance</summary>
        protected static RemoteApi api = null;

        /// <summary>Session identifier</summary>
        protected static string token = null;

        /// <summary>System admin user returned by login</summary>
        private static UserDto sysadmin;

        private const string defaultSysUser = "bond"; 

        static void Main(string[] args)
        {
            // Set command line arguments
            Arguments arguments = new Arguments(args);
            if (arguments.Count < 2)
            {
                Console.WriteLine("Usage: IssueSample.exe [-protocol [http|https] -host <cb-url> -port <cb-port> " + 
                    "-ctx <cb-context> -pwd <default-sysadmin-pwd>]" + 
                    " -userId <userId> -trackerId <trackerId>");
                Console.WriteLine("opt:\tprotocol   - connection protocol type (http by default)");
                Console.WriteLine("\thost      - hostname of the CB server (localhost by default)");
                Console.WriteLine("\tport      - port of the CB service (8080 by default)");
                Console.WriteLine("\tctx       - context path of the CB service ('/cb' by default)");
                Console.WriteLine("\tpwd       - password of default CB sysadmin (password of 'bond')");
                Console.WriteLine("req:\tuserId    - valid CB user id (number)");
                Console.WriteLine("\ttrackerId - valid CB tracker id (number)");
                return;
            }
            
            if (arguments["host"] != null)
            {    
                hostname = arguments["host"];
            }

            if (arguments["protocol"] != null)
            {
                protocol = arguments["protocol"];
                if (protocol.Equals("https"))
                {
                    ServicePointManager.ServerCertificateValidationCallback =
                        new RemoteCertificateValidationCallback(allowAllCertificateValidation);
                }
            }

            if (arguments["port"] != null)
            {
                port = arguments["port"];
            }
            else
            {
                if (protocol.Equals("https"))
                {
                    port = "443";
                }
            }

            if (arguments["ctx"] != null)
            {
                cbcontext = arguments["ctx"];
                if (!cbcontext.StartsWith("/"))
                {
                    cbcontext = "/" + cbcontext;
                }
            }

            string url = protocol + "://" + hostname + ":" + port + cbcontext + "/remote-api";

            string sysadminPassword = "007";
            if (arguments["pwd"] != null)
            {
                sysadminPassword = arguments["pwd"];
            }            

            // A sort trace information about the remote server url
            Console.WriteLine("Connecting to url: " + url + "...");
            try
            {
                // Create proxy to connect to remote api host
                CHessianProxyFactory factory = new CHessianProxyFactory();
                api = (RemoteApi)factory.Create(typeof(RemoteApi), url);
                // Default system admin is used as remote api connection user
                token = api.login(defaultSysUser, sysadminPassword);
                // Get UserDto object with login user information
                sysadmin = api.getSessionUser(token);
                // Setup parameters for remote call
                int userId = Convert.ToInt32(arguments["userid"]);
                int trackerId = Convert.ToInt32(arguments["trackerid"]);
                // Find tracker items for user in CB
                TrackerItemDto[] items = api.findTrackerItemsByTrackerIdAndUserId(token, trackerId, userId);
                // Write out table header
                Console.WriteLine("Id\tName\tSubmittedAt\t\tModifiedAt");
                // Iterate over returned array and write out some of its parameters
                foreach (TrackerItemDto item in items)
                {
                    Console.WriteLine(item.Id + "\t" + item.Name + "\t" + item.SubmittedAt + "\t" + item.ModifiedAt);
                }
            }
            catch (Exception ex)
            {
                Console.WriteLine("Exception occured: " + ex.ToString());
            }
            // Logout from resources
            api.logout(token);
        }
        
        public static bool allowAllCertificateValidation(Object sender, X509Certificate cert, X509Chain chain, SslPolicyErrors Errors)
        {
            return true;
        }
    }
}
